##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/users/operation/UserAdminCheck)Check administrator account existence
Check if an administrator account exists in the database. **Access policy** : public
### Responses
**204**
Success
**404**
User not found
get/users/admin/check
https://api-docs.portainer.io/api/users/admin/check
